Improve this doc View Source

The ngClick directive allows you to specify custom behavior when an element is clicked.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as attribute:

      <ANY
        ng-click="">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngClick | expression | Expression to evaluate upon click. (Event object is available as `$event`)

## Example

Edit in Plunker

    <button ng-click="count = count + 1" ng-init="count=0">
      Increment
    </button>
    count: {{count}}

    it('should check ng-click', function() {
      expect(element(by.binding('count')).getText()).toMatch('0');
      element(by.css('button')).click();
      expect(element(by.binding('count')).getText()).toMatch('1');
    });